import unittest
import os
import argparse
import shutil
import ios2andres as converter
import filecmp
from resource_type import ResourceType


class TestiOS2AndroidRes(unittest.TestCase):

    def setUp(self):
        # save cwd so we can revert back to it when we're done with a test
        self.cwd = os.getcwd()

    def test_processFiles(self):
        converter.processFiles('./test/img/', 'output/', 'ic_')
        os.chdir(self.cwd)
        self.assertTrue(filecmp.cmp(
            './test/img/android-body@1.5x.png',
            'output/drawable-hdpi/ic_android_body.png'))
        self.assertTrue(filecmp.cmp(
            './test/img/android-body@2x.png',
            'output/drawable-xhdpi/ic_android_body.png'))
        self.assertTrue(filecmp.cmp(
            './test/img/android-body@3x.png',
            'output/drawable-xxhdpi/ic_android_body.png'))
        self.assertTrue(filecmp.cmp(
            './test/img/android-body@4x.png',
            'output/drawable-xxxhdpi/ic_android_body.png'))
        self.assertTrue(filecmp.cmp(
            './test/img/android-boat.png',
            'output/drawable/ic_android_boat.png'))

        shutil.rmtree('output')

    def test_createAndroidName(self):
        self.assertEquals(
            'drawable-hdpi/ic_ios_name_convention.png',
            converter.createAndroidName(
                converter.HDPI,
                '/Path/To/File/ios-name-convention@1.5x.png',
                'ic_'))

    def tearDown(self):
        os.chdir(self.cwd)

if __name__ == '__main__':
    unittest.main()



import os
from shutil import copyfile
from resource_type import ResourceType
import argparse

ORIG_DIR = os.getcwd()

NODPI = ResourceType('drawable', '')
LDPI = ResourceType('drawable-ldpi', '.75x')
MDPI = ResourceType('drawable-mdpi', '1x')
HDPI = ResourceType('drawable-hdpi', '1.5x')
XHDPI = ResourceType('drawable-xhdpi', '2x')
XXHDPI = ResourceType('drawable-xxhdpi', '3x')
XXXHDPI = ResourceType('drawable-xxxhdpi', '4x')


def main():

    # parse command line arguments
    input_dir, output_dir, prefix = parseArgs()

    processFiles(input_dir, output_dir, prefix)


def processFiles(input_dir, output_dir, prefix):

    # register resource types
    resources = []
    resources.append(LDPI)
    resources.append(MDPI)
    resources.append(HDPI)
    resources.append(XHDPI)
    resources.append(XXHDPI)
    resources.append(XXXHDPI)
    resources.append(NODPI)

    # wor in the input directory
    os.chdir(input_dir)
    input_dir = os.getcwd()

    # get all files
    onlyfiles = [f for f in os.listdir('.')
                 if os.path.isfile(os.path.join('.', f))]

    # map files into appropriate resources
    for fname in onlyfiles:
        for resourceType in resources:
            if (resourceType.scaleFactor in fname):
                resourceType.addFile(os.path.abspath(fname))
                break

    # move to output directory
    createOutputDir(output_dir)
    os.chdir(output_dir)

    # copy files into new density drawable directories
    for resourceType in resources:
        if (resourceType.files != []):
            createDirectory(resourceType.dirName)
            for fname in resourceType.files:
                copyfile(fname, createAndroidName(resourceType, fname, prefix))


def createDirectory(directory):
    if not os.path.exists(directory):
        os.makedirs(directory)


def parseArgs(args=None):
    parser = argparse.ArgumentParser()
    parser.add_argument('--input',
                        help='Path to the input directory. If not '
                        'specified it assumes current directory',
                        default='.')
    parser.add_argument('--output',
                        help='Path to the output directory. If not specified '
                        'it will create create new resource directories '
                        'within the current directory',
                        default='.')
    parser.add_argument('--prefix',
                        help='Prefix to the asset file names',
                        default='')
    args = parser.parse_args(args) if args is not None else parser.parse_args()
    return args.input, args.output, args.prefix


def createOutputDir(out_path):
    # create output directory
    os.chdir(ORIG_DIR)
    if not os.path.exists(out_path):
        os.makedirs(out_path)


def createAndroidName(resource, path, prefix):
    fname = os.path.basename(path).replace('@' + resource.scaleFactor, '')
    fname = fname.replace('-', '_')
    return resource.dirName + "/" + prefix + fname


if __name__ == "__main__":
    main()



import os
import sys
from setuptools import setup, find_packages

version = '0.1.5'

def read(f):
    return open(os.path.join(os.path.dirname(__file__), f)).read().strip()


setup(name='ios2andres',
      version=version,
      description=('iOS to Android Resource Renamer'),
      long_description='\n\n'.join((read('README.md'), read('CHANGELOG'))),
      classifiers=[
          'License :: OSI Approved :: BSD License',
          'Intended Audience :: Developers',
          'Programming Language :: Python'],
      keywords='android resources ios convert',
      author='Jordan Jozwiak',
      author_email='support@jozapps.com',
      url='https://github.com/jordanjoz1/ios2androidres',
      license='MIT',
      py_modules=['ios2andres'],
      namespace_packages=[],
      install_requires = [],
      entry_points={
          'console_scripts': [
              'ios2andres = ios2andres:main']
      },
      include_package_data = False)